@@ -15,7 +15,7 @@ from clickable.logger import logger, log_file, console_handler
 from clickable.exceptions import ClickableException
 
 
-__version__ = '6.16.0'
+__version__ = '6.19.0'
 __container_minimum_required__ = 2
 
 
@@ -84,7 +84,7 @@ class Clickable(object):
         parser.add_argument(
             '--arch',
             '-a',
-            help='Use the specified arch when building (ignores the setting in clickable.json)'
+            help='Use the specified arch when building'
         )
         parser.add_argument(
             '--verbose',
@@ -113,7 +113,7 @@ class Clickable(object):
         parser.add_argument(
             '--dirty',
             action='store_true',
-            help='Do not clean build directory',
+            help='Do not clean build directory (affects default command chain and desktop command)',
             default=False,
         )
         parser.add_argument(
@@ -142,12 +142,12 @@ class Clickable(object):
         )
         parser.add_argument(
             '--gdbserver',
-            help='Start gdbserver at the given port to debug the app remotely (only desktop mode)',
+            help='Start gdbserver at the given port to debug the app remotely (only desktop mode, for on-device-debugging use gdbserver sub-command instead)',
         )
         parser.add_argument(
             '--gdb',
             action='store_true',
-            help='Start gdb to debug the app (only desktop mode)',
+            help='Start gdb to debug the app (only desktop mode, for on-device-debugging use gdb sub-command instead)',
             default=False,
         )
         parser.add_argument(
@@ -172,6 +172,18 @@ class Clickable(object):
             help='Start app without building it first (only desktop mode)',
             default=False,
         )
+        parser.add_argument(
+            '--non-interactive',
+            action='store_true',
+            help='Do not show prompts for anything (meant for CIs and integration into other tools)',
+            default=False,
+        )
+        parser.add_argument(
+            '--skip-review',
+            action='store_true',
+            help='Do not review click package after build (useful for unconfined apps)',
+            default=False,
+        )
         return parser
 
     def parse_args(self):
@@ -271,6 +283,9 @@ def main():
         ))
 
         sys.exit(2)
+    except KeyboardInterrupt as e:
+        logger.info('') # Print an empty space at then end so the cli prompt is nicer
+        sys.exit(0)
     except Exception as e:
         if isinstance(e, OSError) and '28' in str(e):
             logger.critical('No space left on device')
